@@ -9,5 +9,5 @@ def list_admins():
     ldap_url = 'ldap://' + ARCHIVEOS_DOMAIN
     connect = ldap.initialize(ldap_url)
     connect.simple_bind_s()
-    r = connect.search_s(ARCHIVEOS_BASEDN, ldap.SCOPE_SUBTREE, 'uid=*', displayName)
+    r = connect.search_s(ARCHIVEOS_BASEDN, ldap.SCOPE_SUBTREE, 'uid=*', ['displayName'])
     return r
